import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'
import defAva from '@/assets/images/profile.jpg'

import { getnotice } from "@/api/pms/notice"
const useUserStore = defineStore(
  'user',
  {
    state: () => ({
      token: getToken(),
      id: '',
      name: '',
      avatar: '',
      roles: [],
      permissions: [],
      userCode: '',
      noticeList: []
    }),
    actions: {
      // 登录
      login(userInfo) {
        const username = userInfo.username.trim()
        const password = userInfo.password
        const code = userInfo.code
        const uuid = userInfo.uuid
        const devCode = userInfo.devCode
        const sn = userInfo.sn
        return new Promise((resolve, reject) => {
          login(username, password, code, uuid, devCode, sn).then(res => {
            if (res.devCode && res.sn) {
              let devStorage = { devCode: res.devCode, sn: res.sn }
              localStorage.setItem('devStorage', JSON.stringify(devStorage))
            }
            setToken(res.token)
            this.token = res.token
            resolve()
          }).catch(error => {
            reject(error)
          })
        })
      },
      // 获取用户信息
      getInfo() {
        return new Promise((resolve, reject) => {
          getInfo().then(res => {
            const user = res.user
            const avatar = (user.avatar == "" || user.avatar == null) ? defAva : import.meta.env.VITE_APP_BASE_API + user.avatar;

            if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
              this.roles = res.roles
              this.permissions = res.permissions
            } else {
              this.roles = ['ROLE_DEFAULT']
            }
            this.id = user.userId
            this.name = user.userName
            this.avatar = avatar
            this.userCode = user.code

            this.noticeFun()
            resolve(res)
          }).catch(error => {
            reject(error)
          })
        })
      },
      // 退出系统
      logOut() {
        return new Promise((resolve, reject) => {
          logout(this.token).then(() => {
            this.token = ''
            this.roles = []
            this.permissions = []
            removeToken()
            resolve()
          }).catch(error => {
            reject(error)
          })
        })
      },
      //获取消息
      noticeFun() {
        let devCode = JSON.parse(localStorage.getItem('devStorage')).devCode||""
        let userCode = this.userCode
        getnotice({devCode,userCode}).then(res => {
          this.noticeList = res.data.map(item => {
            return {msg:item}
          })
        })

      }
    }
  })

export default useUserStore
